==> xinit-1.3.4-8.tar.xz: etc/postinstall/xinit.sh <==
if [ ! -f /etc/X11/xinit/startxwinrc ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/startxwinrc /etc/X11/xinit/startxwinrc
fi

if [ ! -f /etc/X11/xinit/Xclients ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/Xclients /etc/X11/xinit/Xclients
fi

if [ ! -f /etc/X11/xinit/xinitrc ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc /etc/X11/xinit/xinitrc
fi

if [ ! -f /etc/X11/xinit/xinitrc-common ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc-common /etc/X11/xinit/xinitrc-common
fi

if [ ! -f /etc/X11/xinit/xinitrc.d/localuser.sh ]
then
    /usr/bin/mkdir -p /etc/X11/xinit/xinitrc.d
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc.d/localuser.sh /etc/X11/xinit/xinitrc.d/localuser.sh
fi

if [ ! -f /etc/X11/xinit/Xsession ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/Xsession /etc/X11/xinit/Xsession
fi

if [ ! -f /etc/X11/Xmodmap ]
then
    /usr/bin/mkdir -p /etc/X11
    /usr/bin/cp /etc/defaults/etc/X11/Xmodmap /etc/X11/Xmodmap
fi

if [ ! -f /etc/X11/Xresources ]
then
    /usr/bin/mkdir -p /etc/X11
    /usr/bin/cp /etc/defaults/etc/X11/Xresources /etc/X11/Xresources
fi

case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/XWin Server" -a "--quote /usr/bin/bash.exe -l -c \"cd; /usr/bin/startxwin\"" /usr/bin/run.exe
if [ -x /usr/bin/gtk-update-icon-cache.exe ]
then
    /usr/bin/gtk-update-icon-cache --force /usr/share/icons/hicolor
fi

case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/User script" -a "--quote /usr/bin/bash.exe -l -c \"cd; /usr/bin/startx /etc/X11/xinit/Xsession xinit-compat\"" /usr/bin/run.exe

==> xinit-1.3.4-12.tar.xz: etc/postinstall/xinit.sh <==
if [ ! -f /etc/X11/xinit/startxwinrc ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/startxwinrc /etc/X11/xinit/startxwinrc
fi

if [ ! -f /etc/X11/xinit/Xclients ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/Xclients /etc/X11/xinit/Xclients
fi

if [ ! -f /etc/X11/xinit/xinitrc ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc /etc/X11/xinit/xinitrc
fi

if [ ! -f /etc/X11/xinit/xinitrc-common ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc-common /etc/X11/xinit/xinitrc-common
fi

if [ ! -f /etc/X11/xinit/xinitrc.d/localuser.sh ]
then
    /usr/bin/mkdir -p /etc/X11/xinit/xinitrc.d
    /usr/bin/cp /etc/defaults/etc/X11/xinit/xinitrc.d/localuser.sh /etc/X11/xinit/xinitrc.d/localuser.sh
fi

if [ ! -f /etc/X11/xinit/Xsession ]
then
    /usr/bin/mkdir -p /etc/X11/xinit
    /usr/bin/cp /etc/defaults/etc/X11/xinit/Xsession /etc/X11/xinit/Xsession
fi

if [ ! -f /etc/X11/Xmodmap ]
then
    /usr/bin/mkdir -p /etc/X11
    /usr/bin/cp /etc/defaults/etc/X11/Xmodmap /etc/X11/Xmodmap
fi

if [ ! -f /etc/X11/Xresources ]
then
    /usr/bin/mkdir -p /etc/X11
    /usr/bin/cp /etc/defaults/etc/X11/Xresources /etc/X11/Xresources
fi

case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/XWin Server" -a "--quote /usr/bin/bash.exe -l -c \"cd; exec /usr/bin/startxwin\"" /usr/bin/run.exe
rm -f /usr/share/icons/hicolor/icon-theme.cache
case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/User script" -a "--quote /usr/bin/bash.exe -l -c \"cd; exec /usr/bin/startx /etc/X11/xinit/Xsession xinit-compat\"" /usr/bin/run.exe
